@@ -19,18 +19,16 @@ import javax.swing.ImageIcon;
 import javax.swing.JButton;
 import javax.swing.JComboBox;
 import javax.swing.JLabel;
+import javax.swing.JOptionPane;
 import javax.swing.JPanel;
 import javax.swing.JRadioButton;
-import javax.swing.JTextField;
 
 import org.af.commons.widgets.DesktopPaneBG;
+import org.af.commons.widgets.validate.RealTextField;
 import org.af.gMCP.config.Configuration;
 import org.af.gMCP.gui.CreateGraphGUI;
 import org.af.gMCP.gui.RControl;
-import org.af.gMCP.gui.dialogs.GroupDialog;
-import org.af.jhlir.call.RChar;
-import org.af.jhlir.call.RInteger;
-import org.af.jhlir.call.RList;
+import org.af.gMCP.gui.dialogs.MatrixCreationDialog;
 import org.apache.commons.lang.ArrayUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -47,7 +45,7 @@ public class PView extends JPanel implements KeyListener, ActionListener {
 	JLabel statusLabel = new JLabel("");
 	JLabel weightLabel = new JLabel("Weight");
 	JLabel alphaLabel = new JLabel("Total α: ");
-	JTextField totalAlpha = new JTextField("0.05");
+	RealTextField totalAlpha = new RealTextField("totalAlpha", 0, 1);
 	GridBagConstraints c = new GridBagConstraints();
 	CreateGraphGUI parent;
 	JButton jbLoadPValues = new JButton("Load p-values from R"); 
@@ -140,6 +138,8 @@ public class PView extends JPanel implements KeyListener, ActionListener {
 		row += 2;
 		panel.add(alphaLabel, cc.xy(2, row));    	
     	panel.add(totalAlpha, cc.xy(4, row));
+    	totalAlpha.setText("0.05");
+    	totalAlpha.addKeyListener(this);
     	
     	updateLabels();
 		panel.revalidate();		
@@ -200,6 +200,15 @@ public class PView extends JPanel implements KeyListener, ActionListener {
 		} else {
 			weightLabel.setText("Weight");
 		}
+		refresh.setEnabled(!b);
+		createMatrix.setEnabled(!b);
+		
+		jrbNoCorrelation.setEnabled(!b);
+		jrbRCorrelation.setEnabled(!b);
+	    jrbSimes.setEnabled(!b);
+
+	    jcbCorObject.setEnabled(!b);
+	    jbLoadPValues.setEnabled(!b);
 	}
 
 	public String getPValuesString() {
@@ -221,7 +230,11 @@ public class PView extends JPanel implements KeyListener, ActionListener {
 	}
 
 	public double getTotalAlpha() {
-		return Double.parseDouble(totalAlpha.getText());
+		try {
+			return Double.parseDouble(totalAlpha.getText());
+		} catch (NumberFormatException e) {
+			return 1;
+		}
 	}
 
 	public void keyPressed(KeyEvent e) {keyTyped(e);}
@@ -229,19 +242,20 @@ public class PView extends JPanel implements KeyListener, ActionListener {
 	public void keyReleased(KeyEvent e) {keyTyped(e);}
 
 	public void keyTyped(KeyEvent e) {
+		parent.getGraphView().setResultUpToDate(false);
 		for (PPanel p : panels) {
 			p.updateMe(false);
 		}
 	}
 	
 	JButton refresh;
+	JButton createMatrix;
 	
 	protected JRadioButton jrbNoCorrelation = new JRadioButton("No Information about correlations");
-    protected JRadioButton jrbStandardCorrelation = new JRadioButton("Select a standard correlation");
+    //protected JRadioButton jrbStandardCorrelation = new JRadioButton("Select a standard correlation");
     protected JRadioButton jrbRCorrelation = new JRadioButton("Select an R correlation matrix");
     protected JRadioButton jrbSimes = new JRadioButton("Correlation applicable for Simes test (new feature that needs still testing)");
 
-    protected JComboBox jcbCorString;
     protected JComboBox jcbCorObject;
     
     JPanel correlatedPanel = null;
@@ -249,44 +263,41 @@ public class PView extends JPanel implements KeyListener, ActionListener {
 	public JPanel getCorrelatedPanel() {
 		
 		if (correlatedPanel!=null) {
-			getPossibleCorrelations();		
+			refresh();		
 			return correlatedPanel;
 		}
 		
 		try {
 			refresh = new JButton(new ImageIcon(ImageIO.read(DesktopPaneBG.class
 					.getResource("/org/af/gMCP/gui/graph/images/update24.png"))));
+			createMatrix = new JButton(new ImageIcon(ImageIO.read(DesktopPaneBG.class
+					.getResource("/org/af/gMCP/gui/graph/images/matrix.png"))));
 		} catch (IOException e) {
 			logger.error("IOError that should never happen.", e);
 		}
 		refresh.setToolTipText("search again for matrices in R");
+		createMatrix.setToolTipText("create matrix with GUI");
 		
 		correlatedPanel = new JPanel();
 		
-		String[] matrices = RControl.getR().eval("gMCP:::getAllQuadraticMatrices()").asRChar().getData();
-		
-	    jcbCorString = new JComboBox(new String[] {});
-	    jcbCorObject = new JComboBox(matrices);
-		
-		if (matrices.length==1 && matrices[0].equals("No quadratic matrices found.")) {
-			jcbCorObject.setEnabled(false);
-			jrbRCorrelation.setEnabled(false);
-		}
+	    jcbCorObject = new JComboBox(new String[] {});
+	    jcbCorObject.addActionListener(this);
+	    refresh();
 
 	    jrbNoCorrelation.setSelected(true);
 
 	    ButtonGroup group = new ButtonGroup();
 	    group.add(jrbNoCorrelation);
-	    group.add(jrbStandardCorrelation);
+	    //group.add(jrbStandardCorrelation);
 	    group.add(jrbRCorrelation);
 	    group.add(jrbSimes);
 
 	    jrbNoCorrelation.addActionListener(this);
-	    jrbStandardCorrelation.addActionListener(this);
+	    //jrbStandardCorrelation.addActionListener(this);
 	    jrbRCorrelation.addActionListener(this);
 	    jrbSimes.addActionListener(this);
 		
-        String cols = "5dlu, pref, 5dlu, fill:pref:grow, 5dlu, pref, 5dlu";
+        String cols = "5dlu, pref, 5dlu, fill:pref:grow, 5dlu, pref, 5dlu, pref, 5dlu";
         String rows = "5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu";
         
         FormLayout layout = new FormLayout(cols, rows);
@@ -295,82 +306,87 @@ public class PView extends JPanel implements KeyListener, ActionListener {
 
         int row = 2;
         
-        correlatedPanel.add(jrbNoCorrelation,     cc.xyw(2, row, 3));     
+        correlatedPanel.add(jrbNoCorrelation,     cc.xyw(2, row, 5));     
         
         row += 2;
         
-        correlatedPanel.add(jrbStandardCorrelation,     cc.xy(2, row));
+        /*correlatedPanel.add(jrbStandardCorrelation,     cc.xy(2, row));
         correlatedPanel.add(jcbCorString, cc.xy(4, row));        
         
-        row += 2;
+        row += 2;*/
         
         correlatedPanel.add(jrbRCorrelation,     cc.xy(2, row));
         correlatedPanel.add(jcbCorObject, cc.xy(4, row));
         correlatedPanel.add(refresh, cc.xy(6, row));  
+        correlatedPanel.add(createMatrix, cc.xy(8, row));
+        createMatrix.setEnabled(Configuration.getInstance().getGeneralConfig().experimentalFeatures());
         
         row += 2;
         
-        correlatedPanel.add(jrbSimes,     cc.xyw(2, row, 3));
+        correlatedPanel.add(jrbSimes,     cc.xyw(2, row, 5));
                 
         refresh.addActionListener(this);
+        createMatrix.addActionListener(this);
         
         return correlatedPanel;
 	}
 
-	private void getPossibleCorrelations() {
-		jcbCorString.removeAllItems();
-		int n = parent.getGraphView().getNL().getNodes().size();
-		if (n!=0) {
-			RList list = RControl.getR().eval("gMCP:::getAvailableStandardDesigns("+n+")").asRList();
-			RChar designs = list.get(0).asRChar();
-			RInteger groups = list.get(1).asRInteger();
-			String[] s = new String[designs.getLength()];
-			for (int i=0; i<s.length; i++) {
-				jcbCorString.addItem(designs.getData()[i] + " ("+ groups.getData()[i]+" groups)"); 
-			}		
-		}
-	}
+	
 
 	public void actionPerformed(ActionEvent e) {
+		parent.getGraphView().setResultUpToDate(false);
 		if (e.getSource()==refresh) {
-			jcbCorObject.removeAllItems();
-			String[] matrices = RControl.getR().eval("gMCP:::getAllQuadraticMatrices()").asRChar().getData();
-			if (matrices.length==1 && matrices[0].equals("No quadratic matrices found.")) {
-				jcbCorObject.setEnabled(false);
-				jrbRCorrelation.setEnabled(false);
-			} else {				
-				jcbCorObject.setEnabled(true);
-				jrbRCorrelation.setEnabled(true);
-			}
-			for (String s : matrices) {
-				jcbCorObject.addItem(s);
-			}
+			refresh();
 		} else if (e.getSource()==jrbNoCorrelation) {
 			if (parent.getGraphView().getNL().getNodes().size()>0) {
 				parent.getGraphView().buttonConfInt.setEnabled(true);
 				parent.getGraphView().buttonadjPval.setEnabled(true);
 			}
-		} else if (e.getSource()==jrbStandardCorrelation || e.getSource()==jrbRCorrelation) {
+		/*}  else if (e.getSource()==jrbStandardCorrelation || e.getSource()==jrbRCorrelation) {
 			parent.getGraphView().buttonConfInt.setEnabled(false);
-			parent.getGraphView().buttonadjPval.setEnabled(true);
+			parent.getGraphView().buttonadjPval.setEnabled(true);*/
 		} else if (e.getSource()==jrbSimes) {
 			parent.getGraphView().buttonConfInt.setEnabled(false);
 			parent.getGraphView().buttonadjPval.setEnabled(false);
 		} else if (e.getSource()==jbLoadPValues) {
 			parent.getGraphView().loadPValuesFromR(); 
+		} else if (e.getSource()==createMatrix) {
+			if (parent.getGraphView().getNL().getNodes().size()<2) {
+				JOptionPane.showMessageDialog(parent, "Correlation makes only sense for more than one hypothesis.", "No correlation for one hypothesis", JOptionPane.ERROR_MESSAGE);
+			} else {
+				new MatrixCreationDialog(parent);
+				refresh();
+			}
+		}
+	}
+
+	private void refresh() {
+		jcbCorObject.removeAllItems();
+		int dim = parent.getGraphView().getNL().getNodes().size();
+		String[] matrices = RControl.getR().eval("gMCP:::getAllQuadraticMatrices(n="+dim+")").asRChar().getData();
+		if (matrices.length==1 && matrices[0].endsWith("matrices found.")) {
+			jcbCorObject.setEnabled(false);
+			jrbRCorrelation.setEnabled(false);
+		} else {				
+			jcbCorObject.setEnabled(true);
+			jrbRCorrelation.setEnabled(true);
+		}
+		for (String s : matrices) {
+			jcbCorObject.addItem(s);
 		}
 	}
 
 	public String getParameters() {
 		String param = "";
-		if (jrbStandardCorrelation.isSelected()) {
+		/* if (jrbStandardCorrelation.isSelected()) {
 			String s = jcbCorString.getSelectedItem().toString();
 			String design = s.substring(0, s.indexOf(" "));
 			String n = s.substring(s.indexOf("(")+1, s.indexOf("groups")-1);
 			logger.warn("Design: \""+design+"\", n=\""+n+"\"");
 			GroupDialog gd = new GroupDialog(parent, Integer.parseInt(n));
 			param = ", correlation=\""+design+"\", samplesize="+gd.getGroups();
-		} else if (jrbRCorrelation.isSelected()) {
+		} else */ 
+		if (jrbRCorrelation.isSelected()) {
 			param = ", correlation="+jcbCorObject.getSelectedItem()+"";
 		} else if (jrbSimes.isSelected()) {
 			param = ", test=\"Simes\"";
