@@ -28,6 +28,14 @@ public class RControlTest {
         Collection collection = new ArrayList();
         assertTrue(collection.isEmpty());
     }
+    
+    @Test
+    public void numericTrabsfer() {
+    	for (int i = 0; i < 1000; i++) {
+    		Double d = RControl.getR().eval("x <- runif(1)").asRNumeric().getData()[0];
+    		assertTrue(RControl.getR().eval("x =="+d).asRLogical().getData()[0]);
+    	}
+    }
 
     @Test(expected= IndexOutOfBoundsException.class) public void empty() { 
         new ArrayList<Object>().get(0); 
